@@ -40,7 +40,6 @@
 #  include "RootAccessibleWrap.h"
 #endif
 #include "States.h"
-#include "Statistics.h"
 #include "TextLeafAccessible.h"
 #include "xpcAccessibleApplication.h"
 
@@ -453,9 +452,9 @@ uint64_t nsAccessibilityService::gCacheDomains =
     nsAccessibilityService::kDefaultCacheDomains;
 
 nsAccessibilityService::nsAccessibilityService()
-    : mHTMLMarkupMap(ArrayLength(sHTMLMarkupMapList)),
-      mMathMLMarkupMap(ArrayLength(sMathMLMarkupMapList)),
-      mXULMarkupMap(ArrayLength(sXULMarkupMapList)) {}
+    : mHTMLMarkupMap(std::size(sHTMLMarkupMapList)),
+      mMathMLMarkupMap(std::size(sMathMLMarkupMapList)),
+      mXULMarkupMap(std::size(sXULMarkupMapList)) {}
 
 nsAccessibilityService::~nsAccessibilityService() {
   NS_ASSERTION(IsShutdown(), "Accessibility wasn't shutdown!");
@@ -568,8 +567,12 @@ void nsAccessibilityService::NotifyOfAnchorJumpTo(nsIContent* aTargetNode) {
   const Accessible* focusedAcc = FocusedAccessible();
   if (focusedAcc &&
       (focusedAcc == document || focusedAcc->IsNonInteractive())) {
-    LocalAccessible* targetAcc = document->GetAccessible(aTargetNode);
-    if (targetAcc) {
+    LocalAccessible* targetAcc =
+        document->GetAccessibleOrContainer(aTargetNode);
+    // If targetAcc is the document, this isn't useful. It's possible we just
+    // haven't built the initial tree yet. Regardless, we don't want to fire an
+    // event for the document here.
+    if (targetAcc && !targetAcc->IsDoc()) {
       nsEventShell::FireEvent(nsIAccessibleEvent::EVENT_SCROLLING_START,
                               targetAcc);
       document->SetAnchorJump(nullptr);
@@ -593,11 +596,14 @@ void nsAccessibilityService::NotifyOfPossibleBoundsChange(
   if (IPCAccessibilityActive()) {
     DocAccessible* document = aPresShell->GetDocAccessible();
     if (document) {
-      // DocAccessible::GetAccessible() won't return the document if a root
-      // element like body is passed.
-      LocalAccessible* accessible = aContent == document->GetContent()
-                                        ? document
-                                        : document->GetAccessible(aContent);
+      LocalAccessible* accessible = document->GetAccessible(aContent);
+      if (!accessible && aContent == document->GetContent()) {
+        // DocAccessible::GetAccessible() won't return the document if a root
+        // element like body is passed. In that case we need the doc accessible
+        // itself.
+        accessible = document;
+      }
+
       if (accessible) {
         document->QueueCacheUpdate(accessible, CacheDomain::Bounds);
       }
@@ -612,11 +618,14 @@ void nsAccessibilityService::NotifyOfComputedStyleChange(
     return;
   }
 
-  // DocAccessible::GetAccessible() won't return the document if a root
-  // element like body is passed.
-  LocalAccessible* accessible = aContent == document->GetContent()
-                                    ? document
-                                    : document->GetAccessible(aContent);
+  LocalAccessible* accessible = document->GetAccessible(aContent);
+  if (!accessible && aContent == document->GetContent()) {
+    // DocAccessible::GetAccessible() won't return the document if a root
+    // element like body is passed. In that case we need the doc accessible
+    // itself.
+    accessible = document;
+  }
+
   if (!accessible && aContent && aContent->HasChildren() &&
       !aContent->IsInNativeAnonymousSubtree()) {
     // If the content has children and its frame has a transform, create an
@@ -1082,10 +1091,10 @@ already_AddRefed<DOMStringList> nsAccessibilityService::GetStringStates(
 void nsAccessibilityService::GetStringEventType(uint32_t aEventType,
                                                 nsAString& aString) {
   static_assert(
-      nsIAccessibleEvent::EVENT_LAST_ENTRY == ArrayLength(kEventTypeNames),
+      nsIAccessibleEvent::EVENT_LAST_ENTRY == std::size(kEventTypeNames),
       "nsIAccessibleEvent constants are out of sync to kEventTypeNames");
 
-  if (aEventType >= ArrayLength(kEventTypeNames)) {
+  if (aEventType >= std::size(kEventTypeNames)) {
     aString.AssignLiteral("unknown");
     return;
   }
@@ -1095,11 +1104,10 @@ void nsAccessibilityService::GetStringEventType(uint32_t aEventType,
 
 void nsAccessibilityService::GetStringEventType(uint32_t aEventType,
                                                 nsACString& aString) {
-  MOZ_ASSERT(
-      nsIAccessibleEvent::EVENT_LAST_ENTRY == ArrayLength(kEventTypeNames),
-      "nsIAccessibleEvent constants are out of sync to kEventTypeNames");
+  MOZ_ASSERT(nsIAccessibleEvent::EVENT_LAST_ENTRY == std::size(kEventTypeNames),
+             "nsIAccessibleEvent constants are out of sync to kEventTypeNames");
 
-  if (aEventType >= ArrayLength(kEventTypeNames)) {
+  if (aEventType >= std::size(kEventTypeNames)) {
     aString.AssignLiteral("unknown");
     return;
   }
@@ -1495,7 +1503,7 @@ LocalAccessible* nsAccessibilityService::CreateAccessible(
 #  include "mozilla/Monitor.h"
 #  include "mozilla/Maybe.h"
 
-static Maybe<Monitor> sAndroidMonitor;
+MOZ_RUNINIT static Maybe<Monitor> sAndroidMonitor;
 
 mozilla::Monitor& nsAccessibilityService::GetAndroidMonitor() {
   if (!sAndroidMonitor.isSome()) {
@@ -1510,7 +1518,7 @@ mozilla::Monitor& nsAccessibilityService::GetAndroidMonitor() {
 // nsAccessibilityService private
 
 bool nsAccessibilityService::Init(uint64_t aCacheDomains) {
-  AUTO_PROFILER_MARKER_TEXT("nsAccessibilityService::Init", A11Y, {}, ""_ns);
+  AUTO_PROFILER_MARKER_UNTYPED("nsAccessibilityService::Init", A11Y, {});
   // DO NOT ADD CODE ABOVE HERE: THIS CODE IS MEASURING TIMINGS.
 
   // Initialize accessible document manager.
@@ -1537,7 +1545,7 @@ bool nsAccessibilityService::Init(uint64_t aCacheDomains) {
 
   eventListenerService->AddListenerChangeListener(this);
 
-  for (uint32_t i = 0; i < ArrayLength(sHTMLMarkupMapList); i++) {
+  for (uint32_t i = 0; i < std::size(sHTMLMarkupMapList); i++) {
     mHTMLMarkupMap.InsertOrUpdate(sHTMLMarkupMapList[i].tag,
                                   &sHTMLMarkupMapList[i]);
   }
@@ -1545,7 +1553,7 @@ bool nsAccessibilityService::Init(uint64_t aCacheDomains) {
     mMathMLMarkupMap.InsertOrUpdate(info.tag, &info);
   }
 
-  for (uint32_t i = 0; i < ArrayLength(sXULMarkupMapList); i++) {
+  for (uint32_t i = 0; i < std::size(sXULMarkupMapList); i++) {
     mXULMarkupMap.InsertOrUpdate(sXULMarkupMapList[i].tag,
                                  &sXULMarkupMapList[i]);
   }
@@ -1583,8 +1591,6 @@ bool nsAccessibilityService::Init(uint64_t aCacheDomains) {
   // domains that we activate based on information about the instantiator.
   gCacheDomains = ::GetCacheDomainsForKnownClients(aCacheDomains);
 
-  statistics::A11yInitialized();
-
   static const char16_t kInitIndicator[] = {'1', 0};
   observerService->NotifyObservers(nullptr, "a11y-init-or-shutdown",
                                    kInitIndicator);
@@ -1756,7 +1762,7 @@ void nsAccessibilityService::MarkupAttributes(
   if (!markupMap) return;
 
   dom::Element* el = aAcc->IsLocal() ? aAcc->AsLocal()->Elm() : nullptr;
-  for (uint32_t i = 0; i < ArrayLength(markupMap->attrs); i++) {
+  for (uint32_t i = 0; i < std::size(markupMap->attrs); i++) {
     const MarkupAttrInfo* info = markupMap->attrs + i;
     if (!info->name) break;
 
@@ -1954,7 +1960,7 @@ nsAccessibilityService* GetOrCreateAccService(uint32_t aNewConsumer,
   return nsAccessibilityService::gAccessibilityService;
 }
 
-void MaybeShutdownAccService(uint32_t aFormerConsumer) {
+void MaybeShutdownAccService(uint32_t aFormerConsumer, bool aAsync) {
   nsAccessibilityService* accService =
       nsAccessibilityService::gAccessibilityService;
 
@@ -1979,11 +1985,32 @@ void MaybeShutdownAccService(uint32_t aFormerConsumer) {
   }
 
   if (nsAccessibilityService::gConsumers & ~aFormerConsumer) {
+    // There are still other consumers of the accessibility service, so we
+    // can't shut down.
     accService->UnsetConsumers(aFormerConsumer);
-  } else {
+    return;
+  }
+
+  if (!aAsync) {
     accService
         ->Shutdown();  // Will unset all nsAccessibilityService::gConsumers
+    return;
   }
+
+  static bool sIsPending = false;
+  if (sIsPending) {
+    // An async shutdown runnable is pending. Don't dispatch another.
+    return;
+  }
+  NS_DispatchToMainThread(NS_NewRunnableFunction(
+      "a11y::MaybeShutdownAccService", [aFormerConsumer]() {
+        // It's possible (albeit very unlikely) that another accessibility
+        // service consumer arrived since this runnable was dispatched. Use
+        // MaybeShutdownAccService to be safe.
+        MaybeShutdownAccService(aFormerConsumer, false);
+        sIsPending = false;
+      }));
+  sIsPending = true;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
