@@ -47,6 +47,9 @@ var gExceptionPaths = [
 
   // toolkit/components/pdfjs/content/build/pdf.js
   "resource://pdf.js/web/images/",
+  // This file is only loaded in using a dynamic import in pdf.js in case wasm
+  // is not available.
+  "resource://pdf.js/web/wasm/openjpeg_nowasm_fallback.js",
 
   // Exclude the form autofill path that has been moved out of the extensions to
   // toolkit, see bug 1691821.
@@ -304,18 +307,16 @@ var allowlist = [
   {
     file: "resource://gre/localization/en-US/netwerk/necko.ftl",
   },
+
+  // A QA and dev debug tool.
+  { file: "chrome://browser/content/places/interactionsViewer.html" },
 ];
 
 if (AppConstants.NIGHTLY_BUILD) {
   allowlist.push(
-    ...[
-      // This is nightly-only debug tool.
-      { file: "chrome://browser/content/places/interactionsViewer.html" },
-
-      // A debug tool that is only available in Nightly builds, and is accessed
-      // directly by developers via the chrome URI (bug 1888491)
-      { file: "chrome://browser/content/backup/debug.html" },
-    ]
+    // A debug tool that is only available in Nightly builds, and is accessed
+    // directly by developers via the chrome URI (bug 1888491)
+    { file: "chrome://browser/content/backup/debug.html" }
   );
 }
 
@@ -367,9 +368,6 @@ const ignorableAllowlist = new Set([
   // The following files are outside of the omni.ja file, so we only catch them
   // when testing on a non-packaged build.
 
-  // toolkit/mozapps/extensions/nsBlocklistService.js
-  "resource://app/blocklist.xml",
-
   // dom/media/gmp/GMPParent.cpp
   "resource://gre/gmp-clearkey/0.1/manifest.json",
 ]);
@@ -483,8 +481,15 @@ function parseManifest(manifestUri) {
             Services.io.newURI(argv[0]).specIgnoringRef
           );
         }
-      } else if (type == "category" && gInterestingCategories.has(argv[0])) {
-        gReferencesFromCode.set(argv[2], null);
+      } else if (type == "category") {
+        if (gInterestingCategories.has(argv[0])) {
+          gReferencesFromCode.set(argv[2], null);
+        } else if (argv[1].startsWith("resource://")) {
+          // Assume that any resource paths immediately after the category name
+          // are for use with BrowserUtils.callModulesFromCategory (rather than
+          // having to hardcode a list of categories in this test).
+          gReferencesFromCode.set(argv[1], null);
+        }
       } else if (type == "resource") {
         trackResourcePrefix(argv[0]);
       } else if (type == "component") {
