@@ -211,7 +211,7 @@ var gMoreFromMozillaPane = {
           "-" +
           this.getTemplateName() +
           `${
-            AppConstants.isChinaRepack() &&
+            BrowserUtils.isChinaRepack() &&
             this.getTemplateName().includes("simple")
               ? "-cn"
               : ""
