@@ -6,10 +6,6 @@ const { TelemetryTestUtils } = ChromeUtils.importESModule(
 
 const CC_NUM_USES_HISTOGRAM = "CREDITCARD_NUM_USES";
 
-function ccFormArgsv1(method, extra) {
-  return ["creditcard", method, "cc_form", undefined, extra];
-}
-
 function ccFormArgsv2(method, extra) {
   return ["creditcard", method, "cc_form_v2", undefined, extra];
 }
@@ -195,10 +191,6 @@ async function openTabAndUseCreditCard(
 }
 
 add_setup(async function () {
-  Services.telemetry.setEventRecordingEnabled("creditcard", true);
-  registerCleanupFunction(async function () {
-    Services.telemetry.setEventRecordingEnabled("creditcard", false);
-  });
   await clearGleanTelemetry();
 });
 
@@ -211,7 +203,6 @@ add_task(async function test_popup_opened() {
   });
 
   Services.telemetry.clearEvents();
-  Services.telemetry.clearScalars();
   await clearGleanTelemetry();
 
   await setStorage(TEST_CREDIT_CARD_1);
@@ -227,24 +218,11 @@ add_task(async function test_popup_opened() {
     }
   );
 
-  await assertTelemetry([
+  await assertTelemetry(undefined, [
     ccFormArgsv2("detected", buildccFormv2Extra({ cc_exp: "false" }, "true")),
-    ccFormArgsv1("detected"),
     ccFormArgsv2("popup_shown", { field_name: "cc-number" }),
-    ccFormArgsv1("popup_shown"),
   ]);
 
-  TelemetryTestUtils.assertScalar(
-    TelemetryTestUtils.getProcessScalars("content"),
-    "formautofill.creditCards.detected_sections_count",
-    1,
-    "There should be 1 section detected."
-  );
-  TelemetryTestUtils.assertScalarUnset(
-    TelemetryTestUtils.getProcessScalars("content"),
-    "formautofill.creditCards.submitted_sections_count"
-  );
-
   await assertGleanTelemetry([
     {
       event_name: "formDetected",
@@ -276,7 +254,6 @@ add_task(async function test_popup_opened_form_without_autocomplete() {
   });
 
   Services.telemetry.clearEvents();
-  Services.telemetry.clearScalars();
   await clearGleanTelemetry();
 
   await setStorage(TEST_CREDIT_CARD_1);
@@ -292,27 +269,14 @@ add_task(async function test_popup_opened_form_without_autocomplete() {
     }
   );
 
-  await assertTelemetry([
+  await assertTelemetry(undefined, [
     ccFormArgsv2(
       "detected",
       buildccFormv2Extra({ cc_number: "1", cc_name: "1", cc_exp: "false" }, "0")
     ),
-    ccFormArgsv1("detected"),
     ccFormArgsv2("popup_shown", { field_name: "cc-number" }),
-    ccFormArgsv1("popup_shown"),
   ]);
 
-  TelemetryTestUtils.assertScalar(
-    TelemetryTestUtils.getProcessScalars("content"),
-    "formautofill.creditCards.detected_sections_count",
-    1,
-    "There should be 1 section detected."
-  );
-  TelemetryTestUtils.assertScalarUnset(
-    TelemetryTestUtils.getProcessScalars("content"),
-    "formautofill.creditCards.submitted_sections_count"
-  );
-
   await assertGleanTelemetry([
     {
       event_name: "formDetected",
@@ -350,7 +314,6 @@ add_task(
     });
 
     Services.telemetry.clearEvents();
-    Services.telemetry.clearScalars();
     await clearGleanTelemetry();
 
     await setStorage(TEST_CREDIT_CARD_1);
@@ -368,11 +331,9 @@ add_task(
       }
     );
 
-    await assertTelemetry([
+    await assertTelemetry(undefined, [
       ccFormArgsv2("detected", buildccFormv2Extra({ cc_number: "1" }, "false")),
-      ccFormArgsv1("detected"),
       ccFormArgsv2("popup_shown", { field_name: "cc-number" }),
-      ccFormArgsv1("popup_shown"),
     ]);
 
     await assertGleanTelemetry([
@@ -404,7 +365,7 @@ add_task(
       }
     );
 
-    await assertTelemetry([
+    await assertTelemetry(undefined, [
       ccFormArgsv2(
         "detected",
         buildccFormv2Extra(
@@ -412,22 +373,9 @@ add_task(
           "false"
         )
       ),
-      ccFormArgsv1("detected"),
       ccFormArgsv2("popup_shown", { field_name: "cc-name" }),
-      ccFormArgsv1("popup_shown"),
     ]);
 
-    TelemetryTestUtils.assertScalar(
-      TelemetryTestUtils.getProcessScalars("content"),
-      "formautofill.creditCards.detected_sections_count",
-      2,
-      "There should be 1 section detected."
-    );
-    TelemetryTestUtils.assertScalarUnset(
-      TelemetryTestUtils.getProcessScalars("content"),
-      "formautofill.creditCards.submitted_sections_count"
-    );
-
     await assertGleanTelemetry([
       {
         event_name: "formDetected",
@@ -511,25 +459,17 @@ add_task(async function test_submit_creditCard_new() {
   }
 
   Services.telemetry.clearEvents();
-  Services.telemetry.clearScalars();
   Services.telemetry.getHistogramById(CC_NUM_USES_HISTOGRAM).clear();
   await clearGleanTelemetry();
 
-  let expected_content = [
+  let expected_parent = [
     ccFormArgsv2("detected", buildccFormv2Extra({ cc_exp: "false" }, "true")),
-    ccFormArgsv1("detected"),
     ccFormArgsv2(
       "submitted",
       buildccFormv2Extra({ cc_exp: "unavailable" }, "user_filled")
     ),
-    ccFormArgsv1("submitted", {
-      // 5 fields plus submit button
-      fields_not_auto: "6",
-      fields_auto: "0",
-      fields_modified: "0",
-    }),
   ];
-  let expected_glean_events = [
+  const expected_glean_events = [
     {
       event_name: "formDetected",
       expected_extra: buildccFormv2Extra(
@@ -547,7 +487,8 @@ add_task(async function test_submit_creditCard_new() {
   ];
   await test_per_command(MAIN_BUTTON, undefined, { 1: 1 }, 1);
 
-  await assertTelemetry(expected_content, [
+  await assertTelemetry(undefined, [
+    ...expected_parent,
     ["creditcard", "show", "capture_doorhanger"],
     ["creditcard", "save", "capture_doorhanger"],
   ]);
@@ -558,7 +499,8 @@ add_task(async function test_submit_creditCard_new() {
 
   await test_per_command(SECONDARY_BUTTON);
 
-  await assertTelemetry(expected_content, [
+  await assertTelemetry(undefined, [
+    ...expected_parent,
     ["creditcard", "show", "capture_doorhanger"],
     ["creditcard", "cancel", "capture_doorhanger"],
   ]);
@@ -569,24 +511,12 @@ add_task(async function test_submit_creditCard_new() {
 
   await test_per_command(MENU_BUTTON, 0);
 
-  await assertTelemetry(expected_content, [
+  await assertTelemetry(undefined, [
+    ...expected_parent,
     ["creditcard", "show", "capture_doorhanger"],
     ["creditcard", "disable", "capture_doorhanger"],
   ]);
 
-  TelemetryTestUtils.assertScalar(
-    TelemetryTestUtils.getProcessScalars("content"),
-    "formautofill.creditCards.detected_sections_count",
-    3,
-    "There should be 3 sections detected."
-  );
-  TelemetryTestUtils.assertScalar(
-    TelemetryTestUtils.getProcessScalars("content"),
-    "formautofill.creditCards.submitted_sections_count",
-    3,
-    "There should be 1 section submitted."
-  );
-
   await assertGleanTelemetry(expected_glean_events);
 });
 
@@ -619,29 +549,18 @@ add_task(async function test_submit_creditCard_autofill() {
 
   SpecialPowers.clearUserPref(ENABLED_AUTOFILL_CREDITCARDS_PREF);
 
-  await assertTelemetry(
-    [
-      ccFormArgsv2("detected", buildccFormv2Extra({ cc_exp: "false" }, "true")),
-      ccFormArgsv1("detected"),
-      ccFormArgsv2("popup_shown", { field_name: "cc-name" }),
-      ccFormArgsv1("popup_shown"),
-      ccFormArgsv2(
-        "filled",
-        buildccFormv2Extra({ cc_exp: "unavailable" }, "filled")
-      ),
-      ccFormArgsv1("filled"),
-      ccFormArgsv2(
-        "submitted",
-        buildccFormv2Extra({ cc_exp: "unavailable" }, "autofilled")
-      ),
-      ccFormArgsv1("submitted", {
-        fields_not_auto: "3",
-        fields_auto: "5",
-        fields_modified: "0",
-      }),
-    ],
-    []
-  );
+  await assertTelemetry(undefined, [
+    ccFormArgsv2("detected", buildccFormv2Extra({ cc_exp: "false" }, "true")),
+    ccFormArgsv2("popup_shown", { field_name: "cc-name" }),
+    ccFormArgsv2(
+      "filled",
+      buildccFormv2Extra({ cc_exp: "unavailable" }, "filled")
+    ),
+    ccFormArgsv2(
+      "submitted",
+      buildccFormv2Extra({ cc_exp: "unavailable" }, "autofilled")
+    ),
+  ]);
 
   await assertGleanTelemetry([
     {
@@ -757,18 +676,14 @@ add_task(async function test_submit_creditCard_update() {
   Services.telemetry.getHistogramById(CC_NUM_USES_HISTOGRAM).clear();
   await clearGleanTelemetry();
 
-  let expected_content = [
+  const expected_parent = [
     ccFormArgsv2("detected", buildccFormv2Extra({ cc_exp: "false" }, "true")),
-    ccFormArgsv1("detected"),
     ccFormArgsv2("popup_shown", { field_name: "cc-name" }),
-    ccFormArgsv1("popup_shown"),
     ccFormArgsv2(
       "filled",
       buildccFormv2Extra({ cc_exp: "unavailable" }, "filled")
     ),
-    ccFormArgsv1("filled"),
     ccFormArgsv2("filled_modified", { field_name: "cc-exp-year" }),
-    ccFormArgsv1("filled_modified", { field_name: "cc-exp-year" }),
     ccFormArgsv2(
       "submitted",
       buildccFormv2Extra(
@@ -776,13 +691,8 @@ add_task(async function test_submit_creditCard_update() {
         "autofilled"
       )
     ),
-    ccFormArgsv1("submitted", {
-      fields_not_auto: "3",
-      fields_auto: "5",
-      fields_modified: "1",
-    }),
   ];
-  let expected_glean_events = [
+  const expected_glean_events = [
     {
       event_name: "formDetected",
       expected_extra: buildccFormv2Extra(
@@ -819,7 +729,8 @@ add_task(async function test_submit_creditCard_update() {
 
   await test_per_command(MAIN_BUTTON, undefined, { 1: 1 }, 1);
 
-  await assertTelemetry(expected_content, [
+  await assertTelemetry(undefined, [
+    ...expected_parent,
     ["creditcard", "show", "update_doorhanger"],
     ["creditcard", "update", "update_doorhanger"],
   ]);
@@ -830,7 +741,8 @@ add_task(async function test_submit_creditCard_update() {
 
   await test_per_command(SECONDARY_BUTTON, undefined, { 0: 1, 1: 1 }, 2);
 
-  await assertTelemetry(expected_content, [
+  await assertTelemetry(undefined, [
+    ...expected_parent,
     ["creditcard", "show", "update_doorhanger"],
     ["creditcard", "save", "update_doorhanger"],
   ]);
@@ -1045,18 +957,15 @@ add_task(async function test_clear_creditCard_autofill() {
     submitForm: false,
   });
 
-  let expected_content = [
+  let expected_parent = [
     ccFormArgsv2("detected", buildccFormv2Extra({ cc_exp: "false" }, "true")),
-    ccFormArgsv1("detected"),
     ccFormArgsv2("popup_shown", { field_name: "cc-name" }),
-    ccFormArgsv1("popup_shown"),
     ccFormArgsv2(
       "filled",
       buildccFormv2Extra({ cc_exp: "unavailable" }, "filled")
     ),
-    ccFormArgsv1("filled"),
   ];
-  await assertTelemetry(expected_content, []);
+  await assertTelemetry(undefined, expected_parent);
 
   await assertGleanTelemetry([
     {
@@ -1095,11 +1004,8 @@ add_task(async function test_clear_creditCard_autofill() {
   // flushing Glean data before tab removal (see Bug 1843178)
   await Services.fog.testFlushAllChildren();
 
-  expected_content = [
-    ccFormArgsv2("popup_shown", { field_name: "cc-number" }),
-    ccFormArgsv1("popup_shown"),
-  ];
-  await assertTelemetry(expected_content, []);
+  expected_parent = [ccFormArgsv2("popup_shown", { field_name: "cc-number" })];
+  await assertTelemetry(undefined, expected_parent);
   await assertGleanTelemetry([
     {
       event_name: "formPopupShown",
@@ -1132,31 +1038,16 @@ add_task(async function test_clear_creditCard_autofill() {
   // flushing Glean data before tab removal (see Bug 1843178)
   await Services.fog.testFlushAllChildren();
 
-  expected_content = [
-    ccFormArgsv2("filled_modified", { field_name: "cc-name" }),
-    ccFormArgsv1("filled_modified", { field_name: "cc-name" }),
-    ccFormArgsv2("filled_modified", { field_name: "cc-number" }),
-    ccFormArgsv1("filled_modified", { field_name: "cc-number" }),
-    ccFormArgsv2("filled_modified", { field_name: "cc-exp-month" }),
-    ccFormArgsv1("filled_modified", { field_name: "cc-exp-month" }),
-    ccFormArgsv2("filled_modified", { field_name: "cc-exp-year" }),
-    ccFormArgsv1("filled_modified", { field_name: "cc-exp-year" }),
-    ccFormArgsv2("filled_modified", { field_name: "cc-type" }),
-    ccFormArgsv1("filled_modified", { field_name: "cc-type" }),
+  expected_parent = [
     ccFormArgsv2("cleared", { field_name: "cc-number" }),
     // popup is shown again because when the field is cleared and is focused,
     // we automatically triggers the popup.
     ccFormArgsv2("popup_shown", { field_name: "cc-number" }),
-    ccFormArgsv1("popup_shown"),
   ];
 
-  await assertTelemetry(expected_content, []);
+  await assertTelemetry(undefined, expected_parent);
 
   await assertGleanTelemetry([
-    {
-      event_name: "formFilledModified",
-      event_count: 5,
-    },
     {
       event_name: "formCleared",
       expected_extra: {
