@@ -9,12 +9,12 @@
 
 import { setSymbols } from "../sources/symbols";
 import { setInScopeLines } from "../ast/index";
-import { prettyPrintAndSelectSource } from "./prettyPrint";
+import { prettyPrintSource, prettyPrintAndSelectSource } from "./prettyPrint";
 import { addTab, closeTab } from "../tabs";
 import { loadSourceText } from "./loadSourceText";
 import { setBreakableLines } from "./breakableLines";
 
-import { prefs } from "../../utils/prefs";
+import { prefs, features } from "../../utils/prefs";
 import { isMinified } from "../../utils/source";
 import { createLocation } from "../../utils/location";
 import {
@@ -157,27 +157,31 @@ async function mayBeSelectMappedSource(location, keepContext, thunkArgs) {
   // If the currently selected source is original, we will
   // automatically map `location` to refer to the original source,
   // even if that used to refer only to the generated source.
-  let shouldSelectOriginalLocation = getShouldSelectOriginalLocation(
-    getState()
-  );
+  let shouldSelectOriginalLocation =
+    getShouldSelectOriginalLocation(getState());
   if (keepContext) {
     // Pretty print source may not be registered yet and getRelatedMapLocation may not return it.
     // Wait for the pretty print source to be fully processed.
+    const sourceHasPrettyTab = hasPrettyTab(getState(), location.source);
     if (
       !location.source.isOriginal &&
       shouldSelectOriginalLocation &&
-      hasPrettyTab(getState(), location.source)
+      sourceHasPrettyTab
     ) {
-      // Note that prettyPrintAndSelectSource has already been called a bit before when this generated source has been added
+      // Note that prettyPrintSource has already been called a bit before when this generated source has been added
       // but it is a slow operation and is most likely not resolved yet.
-      // prettyPrintAndSelectSource uses memoization to avoid doing the operation more than once, while waiting from both callsites.
-      await dispatch(prettyPrintAndSelectSource(location.source));
+      // prettyPrintSource uses memoization to avoid doing the operation more than once, while waiting from both callsites.
+      await dispatch(prettyPrintSource(location.source));
     }
     if (shouldSelectOriginalLocation != location.source.isOriginal) {
-      // Only try to map if the source is mapped. i.e. is original source or a bundle with a valid source map comment
+      // Only try to map the location if the source is mapped:
+      // - mapping from original to generated, if this is original source
+      // - mapping from generated to original, if the generated source has a source map URL comment
+      // - mapping from compressed to pretty print, if the compressed source has a matching pretty print tab opened
       if (
         location.source.isOriginal ||
-        isSourceActorWithSourceMap(getState(), location.sourceActor.id)
+        isSourceActorWithSourceMap(getState(), location.sourceActor.id) ||
+        sourceHasPrettyTab
       ) {
         // getRelatedMapLocation will convert to the related generated/original location.
         // i.e if the original location is passed, the related generated location will be returned and vice versa.
@@ -228,6 +232,7 @@ export function selectLocation(
   location,
   { keepContext = true, highlight = true, scroll = true } = {}
 ) {
+  // eslint-disable-next-line complexity
   return async thunkArgs => {
     const { dispatch, getState, client } = thunkArgs;
 
@@ -278,7 +283,6 @@ export function selectLocation(
     if (!tabExists(getState(), source.id)) {
       dispatch(addTab(source, sourceActor));
     }
-
     dispatch(
       setSelectedLocation(
         location,
@@ -329,7 +333,11 @@ export function selectLocation(
     if (
       selectedFrame &&
       (selectedFrame.location.source.id == location.source.id ||
-        selectedFrame.generatedLocation.source.id == location.source.id)
+        selectedFrame.generatedLocation.source.id == location.source.id) &&
+      // The parser worker only load symbols for in scope lines when CM5 is enabled or
+      // when paused in original sources, as `parserWorker.getClosestFunctionName`
+      // is called when mapping original frames (TODO: Remove when Bug 1943945 is fixed)
+      (!features.codemirrorNext || selectedFrame.location.source.isOriginal)
     ) {
       // This is done from selectLocation and not from paused and selectFrame actions
       // because we may select either original or generated location while being paused
